@@ -9,7 +9,7 @@ from typing import Union, Optional
 
 from .utils.utils import get_api
 from .utils.credential import Credential
-from .utils.network_httpx import Api
+from .utils.network import Api
 
 API = get_api("audio")
 
@@ -45,7 +45,9 @@ class Audio:
 
         api = API["audio_info"]["info"]
         params = {"sid": self.__auid}
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def get_tags(self) -> dict:
         """
@@ -56,7 +58,9 @@ class Audio:
         """
         api = API["audio_info"]["tag"]
         params = {"sid": self.__auid}
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def get_download_url(self) -> dict:
         """
@@ -67,7 +71,9 @@ class Audio:
         """
         api = API["audio_info"]["download_url"]
         params = {"sid": self.__auid, "privilege": 2, "quality": 2}
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def add_coins(self, num: int = 2) -> dict:
         """
@@ -120,7 +126,9 @@ class AudioList:
 
         api = API["list_info"]["info"]
         params = {"sid": self.__amid}
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def get_tags(self) -> dict:
         """
@@ -132,7 +140,9 @@ class AudioList:
 
         api = API["list_info"]["tag"]
         params = {"sid": self.__amid}
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     async def get_song_list(self, pn: int = 1) -> dict:
         """
@@ -147,7 +157,9 @@ class AudioList:
         api = API["list_info"]["song_list"]
         params = {"sid": self.__amid, "pn": pn, "ps": 100}
 
-        return await Api(**api, credential=self.credential).update_params(**params).result
+        return (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
 
     # TODO: 歌单编辑
 
