@@ -14,12 +14,14 @@ import json
 import time
 import uuid
 import base64
+import hashlib
 import tempfile
 import webbrowser
 from typing import Dict, List, Union
 
 import rsa
 import httpx
+import urllib.parse
 import qrcode
 from yarl import URL
 
@@ -28,8 +30,13 @@ from .utils.sync import sync
 from .utils.utils import get_api
 from .utils.credential import Credential
 from .exceptions.LoginError import LoginError
-from .utils.network import to_form_urlencoded
-from .utils.network import HEADERS, get_session, get_spi_buvid_sync
+from .utils.network import to_form_urlencoded, Api
+from .utils.network import (
+    HEADERS,
+    get_session,
+    get_spi_buvid_sync,
+    get_httpx_sync_session,
+)
 from .utils.captcha import get_result, close_server, start_server
 from .utils.safecenter_captcha import get_result as safecenter_get_result
 from .utils.safecenter_captcha import close_server as safecenter_close_server
@@ -52,7 +59,7 @@ id_ = 0  # 事件 id,用于取消 after 绑定
 
 
 def parse_credential_url(events: dict) -> Credential:
-    url = events["data"]["url"]
+    url = events["url"]
     cookies_list = url.split("?")[1].split("&")
     sessdata = ""
     bili_jct = ""
@@ -64,7 +71,7 @@ def parse_credential_url(events: dict) -> Credential:
             bili_jct = cookie[9:]
         if cookie[:11].upper() == "DEDEUSERID=":
             dedeuserid = cookie[11:]
-    ac_time_value = events["data"]["refresh_token"]
+    ac_time_value = events["refresh_token"]
     buvid3 = get_spi_buvid_sync()["b_3"]
     return Credential(
         sessdata=sessdata,
@@ -85,8 +92,8 @@ def make_qrcode(url) -> str:
 
 
 def update_qrcode_data() -> dict:
-    api = API["qrcode"]["get_qrcode_and_token"]
-    qrcode_data = httpx.get(api["url"], follow_redirects=True).json()["data"]
+    api = API["qrcode"]["web"]["get_qrcode_and_token"]
+    qrcode_data = Api(credential=credential, **api).result_sync
     return qrcode_data
 
 
@@ -127,27 +134,27 @@ def login_with_qrcode(root=None) -> Credential:
         global id_
         global start, credential, is_destroy, login_key
         events = login_with_key(login_key)
-        if "code" in events.keys() and events["code"] == 0:
-            if events["data"]["code"] == 86101:
-                log.configure(text="请扫描二维码↑", fg="red", font=big_font)
-            elif events["data"]["code"] == 86090:
-                log.configure(text="点下确认啊！", fg="orange", font=big_font)
-            elif events["data"]["code"] == 86038:
-                raise LoginError("二维码过期，请扫新二维码！")
-            elif events["data"]["code"] == 0:
-                log.configure(text="成功！", fg="green", font=big_font)
-                credential = parse_credential_url(events)
-                root.after(1000, destroy)
-                return 0
-            id_ = root.after(500, update_events)
-            if time.perf_counter() - start > 120:  # 刷新
-                qrcode_data = update_qrcode_data()
-                login_key = qrcode_data["qrcode_key"]
-                qrcode_image = make_qrcode(qrcode_data["url"])
-                photo = PhotoImage(file=qrcode_image)
-                qrcode_label = tkinter.Label(root, image=photo, width=600, height=600)
-                qrcode_label.pack()
-                start = time.perf_counter()
+
+        if events["code"] == 86101:
+            log.configure(text="请扫描二维码↑", fg="red", font=big_font)
+        elif events["code"] == 86090:
+            log.configure(text="点下确认啊！", fg="orange", font=big_font)
+        elif events["code"] == 86038:
+            raise LoginError("二维码过期，请扫新二维码！")
+        elif events["code"] == 0:
+            log.configure(text="成功！", fg="green", font=big_font)
+            credential = parse_credential_url(events)
+            root.after(1000, destroy)
+            return 0
+        id_ = root.after(500, update_events)
+        if time.perf_counter() - start > 120:  # 刷新
+            qrcode_data = update_qrcode_data()
+            login_key = qrcode_data["qrcode_key"]
+            qrcode_image = make_qrcode(qrcode_data["url"])
+            photo = PhotoImage(file=qrcode_image)
+            qrcode_label = tkinter.Label(root, image=photo, width=600, height=600)
+            qrcode_label.pack()
+            start = time.perf_counter()
 
         root.update()
 
@@ -179,38 +186,134 @@ def login_with_qrcode_term() -> Credential:
     print(qrcode_terminal.qr_terminal_str(qrcode_url) + "\n")
     while True:
         events = login_with_key(login_key)
-        if "code" in events.keys() and events["code"] == 0:
-            if events["data"]["code"] == 86101:
-                sys.stdout.write("\r 请扫描二维码↑")
-                sys.stdout.flush()
-            elif events["data"]["code"] == 86090:
-                sys.stdout.write("\r 点下确认啊！")
-                sys.stdout.flush()
-            elif events["data"]["code"] == 86038:
-                print("二维码过期，请扫新二维码！")
-                qrcode_data = update_qrcode_data()
-                qrcode_url = qrcode_data["url"]
-                print(qrcode_terminal.qr_terminal_str(qrcode_url) + "\n")
-            elif events["data"]["code"] == 0:
-                sys.stdout.write("\r 成功！")
-                sys.stdout.flush()
-                return parse_credential_url(events)
-            elif "code" in events.keys():
-                raise LoginError(events["message"])
+        if events["code"] == 86101:
+            sys.stdout.write("\r 请扫描二维码↑")
+            sys.stdout.flush()
+        elif events["code"] == 86090:
+            sys.stdout.write("\r 点下确认啊！")
+            sys.stdout.flush()
+        elif events["code"] == 86038:
+            print("二维码过期，请扫新二维码！")
+            qrcode_data = update_qrcode_data()
+            qrcode_url = qrcode_data["url"]
+            print(qrcode_terminal.qr_terminal_str(qrcode_url) + "\n")
+        elif events["code"] == 0:
+            sys.stdout.write("\r 成功！")
+            sys.stdout.flush()
+            return parse_credential_url(events)
+        elif "code" in events.keys():
+            raise LoginError(events["message"])
         time.sleep(0.5)
 
 
 def login_with_key(key: str) -> dict:
-    params = {"qrcode_key": key, "source": "main-fe-header"}
-    events_api = API["qrcode"]["get_events"]
-    events = httpx.get(
-        events_api["url"],
-        params=params,
-        cookies={"buvid3": str(uuid.uuid1()), "Domain": ".bilibili.com"},
-    ).json()
+    params = {"qrcode_key": key}
+    events_api = API["qrcode"]["web"]["get_events"]
+    events = (
+        Api(credential=credential, **events_api).update_params(**params).result_sync
+    )
     return events
 
 
+# ----------------------------------------------------------------
+# TV 二维码登录
+# ----------------------------------------------------------------
+
+
+def app_signature(params: dict) -> dict:
+    # 这个 APP 签名应该是放在 network 才对的，但暂时没空做 APP 签名，先凑合，咕咕咕
+    appkey = "4409e2ce8ffd12b8"
+    appsec = "59b43e04ad6965f34319062b478f83dd"
+    params["appkey"] = appkey
+    params = dict(sorted(params.items()))
+    params["sign"] = hashlib.md5(
+        (urllib.parse.urlencode(params) + appsec).encode("utf-8")
+    ).hexdigest()
+    return params
+
+
+def update_tv_qrcode_data():
+    api = API["qrcode"]["tv"]["get_qrcode_and_auth_code"]
+    data = app_signature(
+        {
+            "local_id": "0",
+            "ts": int(time.time()),
+        }
+    )
+    qrcode_data = (
+        Api(credential=credential, no_csrf=True, **api).update_data(**data).result_sync
+    )
+    return qrcode_data
+
+
+def verify_tv_login_status(auth_code: str) -> dict:
+    data = app_signature(
+        {
+            "auth_code": auth_code,
+            "ts": int(time.time()),
+            "local_id": "0",
+        }
+    )
+    events_api = API["qrcode"]["tv"]["get_events"]
+    events = (
+        Api(credential=credential, no_csrf=True, **events_api)
+        .update_data(**data)
+        .request_sync(raw=True)
+    )
+    return events
+
+
+def parse_tv_resp(events: dict) -> Credential:
+    cookies = {}
+    for cookie in events["cookie_info"]["cookies"]:
+        if cookie["name"] == "SESSDATA":
+            cookies["sessdata"] = cookie["value"]
+        elif cookie["name"] == "bili_jct":
+            cookies["bili_jct"] = cookie["value"]
+        elif cookie["name"] == "DedeUserID":
+            cookies["dedeuserid"] = cookie["value"]
+
+    return Credential(**cookies)
+
+
+def login_with_tv_qrcode_term() -> Credential:
+    """
+    终端扫描 TV 二维码登录
+
+    Args:
+
+    Returns:
+        Credential: 凭据
+    """
+    import qrcode_terminal
+
+    qrcode_data = update_tv_qrcode_data()
+    qrcode_url = qrcode_data["url"]
+    auth_code = qrcode_data["auth_code"]
+    print(qrcode_terminal.qr_terminal_str(qrcode_url) + "\n")
+    while True:
+        events = verify_tv_login_status(auth_code=auth_code)
+        if events["code"] == 86039:
+            sys.stdout.write("\r 请扫描二维码↑")
+            sys.stdout.flush()
+        # elif events["code"] == 86090: # 根本没捕捉到这个 code
+        #     sys.stdout.write("\r 点下确认啊！")
+        #     sys.stdout.flush()
+        elif events["code"] == 86038:
+            print("二维码过期，请扫新二维码！")
+            qrcode_data = update_tv_qrcode_data()
+            qrcode_url = qrcode_data["url"]
+            auth_code = qrcode_data["auth_code"]
+            print(qrcode_terminal.qr_terminal_str(qrcode_url) + "\n")
+        elif events["code"] == 0:
+            sys.stdout.write("\r 成功！")
+            sys.stdout.flush()
+            return parse_tv_resp(events["data"])
+        elif "code" in events.keys():
+            raise LoginError(events["message"])
+        time.sleep(0.5)
+
+
 # ----------------------------------------------------------------
 # 密码登录
 # ----------------------------------------------------------------
@@ -256,8 +359,8 @@ def login_with_password(username: str, password: str) -> Union[Credential, "Chec
     """
     api_token = API["password"]["get_token"]
     geetest_data = get_geetest()
-    sess = httpx.Client()
-    token_data = json.loads(sess.get(api_token["url"]).text)
+    sess = get_httpx_sync_session()
+    token_data = json.loads(sess.get(api_token["url"], headers=HEADERS).text)
     hash_ = token_data["data"]["hash"]
     key = token_data["data"]["key"]
     final_password = encrypt(hash_, key, password)
@@ -462,29 +565,27 @@ def send_sms(phonenumber: PhoneNumber) -> None:
     code = phonenumber.code
     tell = phonenumber.number
     geetest_data = get_geetest()
-    sess = get_session()
+    sess = get_httpx_sync_session()
     return_data = json.loads(
-        sync(
-            sess.post(
-                url=api["url"],
-                data=to_form_urlencoded(
-                    {
-                        "source": "main-fe-header",
-                        "tel": tell,
-                        "cid": code,
-                        "validate": geetest_data["validate"],  # type: ignore
-                        "token": geetest_data["token"],  # type: ignore
-                        "seccode": geetest_data["seccode"],  # type: ignore
-                        "challenge": geetest_data["challenge"],  # type: ignore
-                    }
-                ),
-                headers={
-                    "User-Agent": "Mozilla/5.0",
-                    "Referer": "https://www.bilibili.com",
-                    "Content-Type": "application/x-www-form-urlencoded",
-                },
-                cookies={"buvid3": "E9BAB99E-FE1E-981E-F772-958B7F572FF487330infoc"},
-            )
+        sess.post(
+            url=api["url"],
+            data=to_form_urlencoded(
+                {
+                    "source": "main-fe-header",
+                    "tel": tell,
+                    "cid": code,
+                    "validate": geetest_data["validate"],  # type: ignore
+                    "token": geetest_data["token"],  # type: ignore
+                    "seccode": geetest_data["seccode"],  # type: ignore
+                    "challenge": geetest_data["challenge"],  # type: ignore
+                }
+            ),
+            headers={
+                "User-Agent": "Mozilla/5.0",
+                "Referer": "https://www.bilibili.com",
+                "Content-Type": "application/x-www-form-urlencoded",
+            },
+            cookies={"buvid3": "E9BAB99E-FE1E-981E-F772-958B7F572FF487330infoc"},
         ).text
     )
     if return_data["code"] == 0:
@@ -505,25 +606,23 @@ def login_with_sms(phonenumber: PhoneNumber, code: str) -> Credential:
         Credential: 凭据类
     """
     global captcha_id
-    sess = get_session()
+    sess = get_httpx_sync_session()
     api = API["sms"]["login"]
     if captcha_id == None:
         raise LoginError("请申请或重新申请发送验证码")
     return_data = json.loads(
-        sync(
-            sess.request(
-                "POST",
-                url=api["url"],
-                data={
-                    "tel": phonenumber.number,
-                    "cid": phonenumber.code,
-                    "code": code,
-                    "source": "main_web",
-                    "captcha_key": captcha_id,
-                    "keep": "true",
-                },
-                headers=HEADERS,
-            )
+        sess.request(
+            "POST",
+            url=api["url"],
+            data={
+                "tel": phonenumber.number,
+                "cid": phonenumber.code,
+                "code": code,
+                "source": "main_web",
+                "captcha_key": captcha_id,
+                "keep": "true",
+            },
+            headers=HEADERS,
         ).text
     )
     # return_data["status"] 已改为 return_data["data"]["status"]
@@ -601,4 +700,4 @@ class Check:
         api = API["safecenter"]["check_info"]
         self.tmp_token = self.check_url.split("?")[1].split("&")[0][10:]
         params = {"tmp_code": self.tmp_token}
-        return json.loads(httpx.get(api["url"], params=params).text)["data"]
+        return Api(credential=credential, **api, params=params).result_sync
