@@ -9,6 +9,7 @@ import time
 import asyncio
 import logging
 import datetime
+from enum import Enum
 from typing import Union, Optional
 
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
@@ -17,7 +18,7 @@ from bilibili_api.exceptions import ApiException
 
 from .video import Video
 from .user import get_self_info
-from .utils.utils import get_api
+from .utils.utils import get_api, raise_for_statement
 from .utils.picture import Picture
 from .utils.AsyncEvent import AsyncEvent
 from .utils.credential import Credential
@@ -236,69 +237,28 @@ async def get_session_settings(credential: Credential) -> dict:
     return await Api(**api, credential=credential).result
 
 
-async def send_msg(
-    credential: Credential,
-    receiver_id: int,
-    msg_type: str,
-    content: Union[str, Picture],
-) -> dict:
+class EventType(Enum):
     """
-    给用户发送私聊信息。目前仅支持纯文本。
+    事件类型
 
-    Args:
-        credential  (Credential)   : 凭证
-
-        receiver_id (int)          : 接收者 UID
-
-        msg_type    (str)          : 信息类型，参考 Event 类的时间类型。
-
-        content     (str | Picture): 信息内容。支持文字和图片。
-
-    Returns:
-        dict: 调用 API 返回结果
+    - TEXT:           纯文字消息
+    - PICTURE:        图片消息
+    - WITHDRAW:       撤回消息
+    - GROUPS_PICTURE: 应援团图片，但似乎不常触发，一般使用 PICTURE 即可
+    - SHARE_VIDEO:    分享视频
+    - NOTICE:         系统通知
+    - PUSHED_VIDEO:   UP主推送的视频
+    - WELCOME:        新成员加入应援团欢迎
     """
-    credential.raise_for_no_sessdata()
-    credential.raise_for_no_bili_jct()
 
-    api = API["operate"]["send_msg"]
-    self_info = await get_self_info(credential)
-    sender_uid = self_info["mid"]
-
-    if msg_type == Event.TEXT:
-        real_content = json.dumps({"content": content})
-    elif msg_type == Event.WITHDRAW:
-        real_content = str(content)
-    elif msg_type == Event.PICTURE or msg_type == Event.GROUPS_PICTURE:
-        assert isinstance(content, Picture), TypeError
-        await content.upload_file(credential=credential, data={"biz": "im"})
-        real_content = json.dumps(
-            {
-                "url": content.url,
-                "height": content.height,
-                "width": content.width,
-                "imageType": content.imageType,
-                "original": 1,
-                "size": content.size,
-            }
-        )
-    else:
-        raise ApiException("信息类型不支持。")
-
-    data = {
-        "msg[sender_uid]": sender_uid,
-        "msg[receiver_id]": receiver_id,
-        "msg[receiver_type]": 1,
-        "msg[msg_type]": int(msg_type),
-        "msg[msg_status]": 0,
-        "msg[content]": real_content,
-        "msg[dev_id]": "A6716E9A-7CE3-47AF-994B-F0B34178D28D",
-        "msg[new_face_version]": 0,
-        "msg[timestamp]": int(time.time()),
-        "from_filework": 0,
-        "build": 0,
-        "mobi_app": "web",
-    }
-    return await Api(**api, credential=credential).update_data(**data).result
+    TEXT = 1
+    PICTURE = 2
+    WITHDRAW = 5
+    GROUPS_PICTURE = 6
+    SHARE_VIDEO = 7
+    NOTICE = 10
+    PUSHED_VIDEO = 11
+    WELCOME = 306
 
 
 class Event:
@@ -313,16 +273,6 @@ class Event:
     + msg_key:       事件唯一编号
     + timestamp:     事件时间戳
     + content:       事件内容
-
-    事件类型:
-    + TEXT:           纯文字消息
-    + PICTURE:        图片消息
-    + WITHDRAW:       撤回消息
-    + GROUPS_PICTURE: 应援团图片，但似乎不常触发，一般使用 PICTURE 即可
-    + SHARE_VIDEO:    分享视频
-    + NOTICE:         系统通知
-    + PUSHED_VIDEO:   UP主推送的视频
-    + WELCOME:        新成员加入应援团欢迎
     """
 
     receiver_id: int
@@ -335,15 +285,6 @@ class Event:
     timestamp: int
     content: Union[str, int, Picture, Video]
 
-    TEXT = "1"
-    PICTURE = "2"
-    WITHDRAW = "5"
-    GROUPS_PICTURE = "6"
-    SHARE_VIDEO = "7"
-    NOTICE = "10"
-    PUSHED_VIDEO = "11"
-    WELCOME = "306"
-
     def __init__(self, data: dict, self_uid: int):
         """
         信息事件类型
@@ -359,7 +300,7 @@ class Event:
         try:
             self.__content()
         except AttributeError:
-            print(data)
+            logging.error(f"解析消息错误：{data}")
 
     def __str__(self):
         if self.receiver_type == 1:
@@ -382,39 +323,104 @@ class Event:
         return f"{msg_type} {user_id} 信息 {self.content}({self.timestamp})"  # type: ignore
 
     def __content(self) -> None:
-        """更新消息内容"""
-
+        """
+        更新消息内容
+        """
         content: dict = json.loads(self.content)  # type: ignore
-        mt = str(self.msg_type)
+        mt = self.msg_type
 
-        if mt == Event.TEXT:
+        if mt == EventType.TEXT.value:
             self.content = content.get("content")  # type: ignore
 
-        elif mt == Event.WELCOME:
+        elif mt == EventType.WELCOME.value:
             self.content = content.get("content") + str(content.get("group_id"))  # type: ignore
 
-        elif mt == Event.WITHDRAW:
+        elif mt == EventType.WITHDRAW.value:
             self.content = str(content)
 
-        elif mt == Event.PICTURE or mt == Event.GROUPS_PICTURE:
+        elif mt == EventType.PICTURE.value or mt == EventType.GROUPS_PICTURE.value:
             content.pop("original")
             self.content = Picture(**content)
 
-        elif mt == Event.SHARE_VIDEO or mt == Event.PUSHED_VIDEO:
+        elif mt == EventType.SHARE_VIDEO.value or mt == EventType.PUSHED_VIDEO.value:
             self.content = Video(bvid=content.get("bvid"), aid=content.get("id"))
 
-        elif mt == Event.NOTICE:
+        elif mt == EventType.NOTICE.value:
             self.content = content["title"] + " " + content["text"]
 
         else:
-            print(mt, content)
+            logging.error(f"未知消息类型：{mt}，消息内容：{content}")
+
+
+async def send_msg(
+    credential: Credential,
+    receiver_id: int,
+    msg_type: EventType,
+    content: Union[str, Picture],
+) -> dict:
+    """
+    给用户发送私聊信息。目前仅支持纯文本。
+
+    Args:
+        credential  (Credential)   : 凭证
+
+        receiver_id (int)          : 接收者 UID
+
+        msg_type    (EventType)          : 信息类型，参考 Event 类的事件类型。
+
+        content     (str | Picture): 信息内容。支持文字和图片。
+
+    Returns:
+        dict: 调用 API 返回结果
+    """
+    credential.raise_for_no_sessdata()
+    credential.raise_for_no_bili_jct()
+
+    api = API["operate"]["send_msg"]
+    self_info = await get_self_info(credential)
+    sender_uid = self_info["mid"]
+
+    if msg_type == EventType.TEXT:
+        real_content = json.dumps({"content": content})
+    elif msg_type == EventType.WITHDRAW:
+        real_content = str(content)
+    elif msg_type == EventType.PICTURE or msg_type == EventType.GROUPS_PICTURE:
+        raise_for_statement(isinstance(content, Picture), "TypeError")
+        await content.upload_file(credential=credential, data={"biz": "im"})
+        real_content = json.dumps(
+            {
+                "url": content.url,
+                "height": content.height,
+                "width": content.width,
+                "imageType": content.imageType,
+                "original": 1,
+                "size": content.size,
+            }
+        )
+    else:
+        raise ApiException("信息类型不支持。")
+
+    data = {
+        "msg[sender_uid]": sender_uid,
+        "msg[receiver_id]": receiver_id,
+        "msg[receiver_type]": 1,
+        "msg[msg_type]": msg_type.value,
+        "msg[msg_status]": 0,
+        "msg[content]": real_content,
+        "msg[dev_id]": "A6716E9A-7CE3-47AF-994B-F0B34178D28D",
+        "msg[new_face_version]": 0,
+        "msg[timestamp]": int(time.time()),
+        "from_filework": 0,
+        "build": 0,
+        "mobi_app": "web",
+    }
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 class Session(AsyncEvent):
     """
     会话类，用来开启消息监听。
     """
-
     def __init__(self, credential: Credential, debug=False):
         super().__init__()
         # 会话状态
@@ -447,6 +453,15 @@ class Session(AsyncEvent):
             )
             self.logger.addHandler(handler)
 
+    def on(self, event_type: EventType):
+        """
+        重载装饰器注册事件监听器
+
+        Args:
+            event_type (EventType): 事件类型
+        """
+        return super().on(event_name=str(event_type.value))
+
     def get_status(self) -> int:
         """
         获取连接状态
@@ -456,12 +471,12 @@ class Session(AsyncEvent):
         """
         return self.__status
 
-    async def run(self, except_self: bool = True) -> None:
+    async def run(self, exclude_self: bool = True) -> None:
         """
         非阻塞异步爬虫 定时发送请求获取消息
 
         Args:
-            except_self: bool 是否排除自己发出的消息，默认是
+            exclude_self: bool 是否排除自己发出的消息，默认排除
         """
 
         # 获取自身UID 用于后续判断消息是发送还是接收
@@ -511,7 +526,7 @@ class Session(AsyncEvent):
                         continue
                     for message in result.get("messages", [])[::-1]:
                         event = Event(message, self.uid)
-                        if str(event.msg_type) == Event.WITHDRAW:
+                        if event.msg_type == EventType.WITHDRAW.value:
                             self.logger.info(
                                 str(
                                     self.events.get(
@@ -523,11 +538,11 @@ class Session(AsyncEvent):
                         else:
                             self.logger.info(event)
 
-                        # 自己发出的消息不派发任务
-                        if event.sender_uid != self.uid or not except_self:
+                        # 自己发出的消息不发布任务
+                        if event.sender_uid != self.uid or not exclude_self:
                             self.dispatch(str(event.msg_type), event)
 
-                        self.events.update({str(event.msg_key): event})
+                        self.events[str(event.msg_key)] = event
 
             self.logger.debug(f"maxTs = {self.maxTs}")
 
@@ -535,15 +550,15 @@ class Session(AsyncEvent):
         self.sched.start()
         self.logger.info("开始轮询")
 
-    async def start(self, except_self: bool = True) -> None:
+    async def start(self, exclude_self: bool = True) -> None:
         """
         阻塞异步启动 通过调用 self.close() 后可断开连接
 
         Args:
-            except_self: bool 是否排除自己发出的消息，默认是
+            exclude_self: bool 是否排除自己发出的消息，默认排除
         """
 
-        await self.run(except_self)
+        await self.run(exclude_self)
         while self.get_status() < 2:
             await asyncio.sleep(1)
 
@@ -566,7 +581,9 @@ class Session(AsyncEvent):
         if self.uid == event.sender_uid:
             self.logger.error("不能给自己发送消息哦~")
         else:
-            msg_type = Event.PICTURE if isinstance(content, Picture) else Event.TEXT
+            msg_type = (
+                EventType.PICTURE if isinstance(content, Picture) else EventType.TEXT
+            )
             return await send_msg(self.credential, event.sender_uid, msg_type, content)
 
     def close(self) -> None:
