@@ -12,6 +12,7 @@ from typing import Tuple, Union, Literal
 import httpx
 from yarl import URL
 
+from .network import Api
 from ..game import Game
 from ..manga import Manga
 from ..topic import Topic
@@ -32,6 +33,8 @@ from ..interactive_video import InteractiveVideo
 from ..favorite_list import FavoriteList, FavoriteListType
 from ..user import User, ChannelSeries, ChannelSeriesType, get_self_info
 
+from .initial_state import get_initial_state
+
 
 class ResourceType(Enum):
     """
@@ -132,7 +135,7 @@ async def parse_link(
             url = "https:" + url
 
         # 转换为 yarl
-        url = URL(url) # type: ignore
+        url = URL(url)  # type: ignore
 
         # 排除小黑屋
         black_room = parse_black_room(url, credential)  # type: ignore
@@ -150,7 +153,7 @@ async def parse_link(
                 return (User(info["mid"], credential=credential), ResourceType.USER)
 
         channel = parse_season_series(
-            url, credential # type: ignore
+            url, credential  # type: ignore
         )  # 不需要 real_url，提前处理
         if channel != -1:
             return (channel, ResourceType.CHANNEL_SERIES)  # type: ignore
@@ -169,10 +172,10 @@ async def parse_link(
         if topic != -1:
             topic.credential = credential  # type: ignore
             return (topic, ResourceType.TOPIC)  # type: ignore
-        bnj_video = parse_bnj(url, credential)  # type: ignore
-        if bnj_video != -1:
-            bnj_video.credential = credential  # type: ignore
-            return (bnj_video, ResourceType.VIDEO)  # type: ignore
+        festival_video = await parse_festival(url, credential)  # type: ignore
+        if festival_video != -1:
+            festival_video.credential = credential  # type: ignore
+            return (festival_video, ResourceType.VIDEO)  # type: ignore
         note = parse_note(url, credential)  # type: ignore
         if note != -1:
             return (note, ResourceType.NOTE)  # type: ignore
@@ -217,7 +220,7 @@ async def parse_link(
         manga = parse_manga(url, credential)  # type: ignore
         if not manga == -1:
             obj = (manga, ResourceType.MANGA)
-        opus_dynamic = parse_opus_dynamic(url, credential) # type: ignore
+        opus_dynamic = parse_opus_dynamic(url, credential)  # type: ignore
         if not opus_dynamic == -1:
             obj = (opus_dynamic, ResourceType.DYNAMIC)
 
@@ -244,7 +247,9 @@ async def auto_convert_video(
 
     # check episode
     if "redirect_url" in video_info:
-        reparse_link = await parse_link(await get_real_url(video_info["redirect_url"]), credential=credential)  # type: ignore
+        reparse_link = await parse_link(
+            await get_real_url(video_info["redirect_url"]), credential=credential
+        )  # type: ignore
         return reparse_link  # type: ignore
 
     # return video
@@ -348,20 +353,12 @@ async def parse_episode(url: URL, credential: Credential) -> Union[Episode, int]
                 epid = int(video_short_id[2:])
                 return Episode(epid=epid)
             elif video_short_id[:2].upper() == "SS":
-                sess = httpx.AsyncClient()
-                html_text = (await sess.get(str(url))).text
-                if "__INITIAL_STATE__" in html_text:
-                    pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
-                    match = re.search(pattern, html_text)
-                    content = json.loads(match.group(1))
-                    epid = content["epInfo"]["id"] if "id" in content["epInfo"] else content["epInfo"]["ep_id"]
-                else:
-                    epid = re.search(r'<link rel="canonical" href="//www.bilibili.com/bangumi/play/ep(\d+)"/>', html_text).group(1)
-                    return Episode(epid=epid, credential=credential)
+                bangumi = Bangumi(ssid=int(video_short_id[2:]))
+                epid = (await bangumi.get_episodes())[0].get_epid()
+                return Episode(epid=epid)
     return -1
 
 
-
 def parse_favorite_list(url: URL, credential: Credential) -> Union[FavoriteList, int]:
     """
     解析收藏夹,如果不是返回 -1，否则返回对应类
@@ -508,9 +505,11 @@ def parse_space_favorite_list(
                 ):  # query 中不存在 fid 则返回默认收藏夹
                     api = get_api("favorite-list")["info"]["list_list"]
                     params = {"up_mid": uid, "type": 2}
-                    favorite_lists = httpx.get(
-                        api["url"], params=params, cookies=credential.get_cookies()
-                    ).json()["data"]
+                    favorite_lists = (
+                        Api(**api, credential=credential)
+                        .update_params(**params)
+                        .result_sync
+                    )
 
                     if favorite_lists == None:
                         return -1
@@ -613,7 +612,6 @@ def parse_topic(url: URL, credential: Credential) -> Union[Topic, int]:
             url.parts[:4] == ("/", "v", "topic", "detail")
             and url.query.get("topic_id") is not None
         ):
-
             return Topic(int(url.query["topic_id"]), credential=credential)
     return -1
 
@@ -624,11 +622,20 @@ def parse_manga(url: URL, credential: Credential) -> Union[Manga, int]:
     return -1
 
 
-def parse_bnj(url: URL, credential: Credential) -> Union[Video, int]:
-    # https://www.bilibili.com/festival/2023bnj?bvid=BV1ZY4y1f79x&spm_id_from=333.999.0.0
+async def parse_festival(url: URL, credential: Credential) -> Union[Video, int]:
     bvid = url.query.get("bvid")
-    if bvid is not None:
+    if bvid is not None:  # get bvid if provided
         return Video(bvid, credential=credential)
+
+    if (
+        url.host == "www.bilibili.com" and url.parts[1] == "festival"
+    ):  # use __initial_state__ to fetch
+        content, content_type = await get_initial_state(
+            url=str(url), credential=credential
+        )
+        return Video(
+            content["videoSections"][0]["episodes"][0]["bvid"], credential=credential
+        )  # 返回当前第一个视频
     return -1
 
 
