@@ -4,12 +4,14 @@ bilibili_api.utils.utils
 通用工具库。
 """
 
-import os
 import json
+import os
+import random
 from typing import List, TypeVar
+from ..exceptions import StatementException
 
 
-def get_api(field: str) -> dict:
+def get_api(field: str, *args) -> dict:
     """
     获取 API。
 
@@ -26,7 +28,10 @@ def get_api(field: str) -> dict:
     )
     if os.path.exists(path):
         with open(path, encoding="utf8") as f:
-            return json.loads(f.read())
+            data = json.load(f)
+            for arg in args:
+                data = data[arg]
+            return data
     else:
         return {}
 
@@ -137,7 +142,7 @@ def join(seperator: str, array: list):
 
     Args:
         seperator (str) : 分隔字符
-        
+
         array     (list): 数组
 
     Returns:
@@ -167,3 +172,41 @@ def chunk(arr: ChunkT, size: int) -> List[ChunkT]:
         result.append(temp)
 
     return result
+
+
+def get_deviceid(separator: str = "-", is_lowercase: bool = False) -> str:
+    """
+    获取随机 deviceid (dev_id)
+
+    Args:
+        separator (str)  : 分隔符 默认为 "-"
+
+        is_lowercase (bool) : 是否以小写形式 默认为False
+
+    参考: https://github.com/SocialSisterYi/bilibili-API-collect/blob/master/docs/message/private_msg.md#发送私信web端
+
+    Returns:
+        str: device_id
+    """
+    template = ["xxxxxxxx", "xxxx", "4xxx", "yxxx", "xxxxxxxxxxxx"]
+    dev_id_group = []
+    for i in range(len(template)):
+        s = ""
+        group = template[i]
+        for k in group:
+            rand: int = int(16 * random.random())
+            if k in "xy":
+                if k == "x":
+                    s += hex(rand)[2:]
+                else:
+                    s += hex(3 & rand | 8)[2:]
+            else:
+                s += "4"
+        dev_id_group.append(s)
+    res = join(separator, dev_id_group)
+    return res if is_lowercase else res.upper()
+
+
+def raise_for_statement(statement: bool, msg: str="未满足条件") -> None:
+    if not statement:
+        raise StatementException(msg=msg)
